@@ -61,7 +61,8 @@ admin.site.register(MeansOfIdentification)
 admin.site.register(MeterRequest)
 admin.site.register(NextOfKin)
 admin.site.register(PaymentVendor)
-admin.site.register(Payment)
+admin.site.register(Earning)
+# admin.site.register(Payment)
 admin.site.register(Product)
 admin.site.register(Purchase)
 admin.site.register(Survey)
