@@ -7,6 +7,7 @@ from .expertise import *
 from .means_of_identification import *
 from .meter_request import *
 from .next_of_kin import *
+from .earnings import *
 from .payment import *
 from .product import *
 from .purchase import *
@@ -20,3 +21,4 @@ from .work_order import *
 from .work_order_material import *
 from .work_order_service import *
 from .work_order_status import *
+from .config import *
